==> form_helper_widget-8.x-0.1.tar.gz: form_helper_widget/src/Routing/RouteSubscriber.php <==
<?php

namespace Drupal\form_helper_widget\Routing;

use Drupal\Core\Entity\EntityManagerInterface;
use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Routing\RoutingEvents;
use Symfony\Component\Routing\RouteCollection;
use Symfony\Component\Routing\Route;

class RouteSubscriber extends RouteSubscriberBase {

  /**
   * The entity type manager
   *
   * @var \Drupal\Core\Entity\EntityManagerInterface
   */
  protected $manager;

  /**
   * Constructs a RouteSubscriber object.
   *
   * @param \Drupal\Core\Entity\EntityManagerInterface $manager
   *   The entity type manager.
   */
  public function __construct(EntityManagerInterface $manager) {
    $this->manager = $manager;
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection) {

    // Create fieldgroup routes for every entity.
    foreach ($this->manager->getDefinitions() as $entity_type_id => $entity_type) {
      $defaults = array();
      if ($route_name = $entity_type->get('field_ui_base_route')) {
        // Try to get the route from the current collection.
        if (!$entity_route = $collection->get($route_name)) {
          continue;
        }
        $path = $entity_route->getPath();

        $options = $entity_route->getOptions();

        // Special parameter used to easily recognize all Field UI routes.
        $options['_field_ui'] = TRUE;

        if (($bundle_entity_type = $entity_type->getBundleEntityType()) && $bundle_entity_type !== 'bundle') {
          $options['parameters'][$entity_type->getBundleEntityType()] = array(
            'type' => 'entity:' . $entity_type->getBundleEntityType(),
          );
        }

        $options['parameters']['field_group'] = array(
          'type' => 'field_group',
          'entity_type' => $entity_type->getBundleEntityType(),
        );

        $defaults_delete = [
          'entity_type_id' => $entity_type_id,
          '_form' => '\Drupal\form_helper_widget\Form\FormHelperWidgetDeleteForm',
        ];
        $defaults_add = [
          'entity_type_id' => $entity_type_id,
          '_form' => '\Drupal\form_helper_widget\Form\FormHelperWidgetAddForm',
          '_title' => 'Add group',
        ];

        // If the entity type has no bundles and it doesn't use {bundle} in its
        // admin path, use the entity type.
        if (strpos($path, '{bundle}') === FALSE) {
          $defaults_add['bundle'] = !$entity_type->hasKey('bundle') ? $entity_type_id : '';
          $defaults_delete['bundle'] = $defaults_add['bundle'];
        }

        // Routes to add translation widget.
        $route = new Route(
          "$path/form-display/add-translation-widget",
          ['context' => 'form'] + $defaults_add,
          array('_permission' => 'administer ' . $entity_type_id . ' form display'),
          $options
        );
        $collection->add("field_ui.form_helper_widget_add_$entity_type_id.form_display", $route);

        // Routes to delete translation widget.
        $route = new Route(
          "/admin/structure/form_helper_widget/{entityTypeId}/{bundle}/{mode}/{widgetId}",
          ['context' => 'form'] + $defaults_delete,
          array('_permission' => 'administer ' . $entity_type_id . ' form display'),
          $options
        );

        $collection->add("field_ui.form_helper_widget_delete_$entity_type_id", $route);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    //$events = parent::getSubscribedEvents();
    // Come after field_ui, config_translation.
    $events[RoutingEvents::ALTER] = array('onAlterRoutes', -210);
    return $events;
  }


}

==> form_helper_widget-8.x-0.3.tar.gz: form_helper_widget/src/Routing/RouteSubscriber.php <==
<?php

namespace Drupal\form_helper_widget\Routing;

use Drupal\Core\Entity\EntityManagerInterface;
use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Routing\RoutingEvents;
use Symfony\Component\Routing\RouteCollection;
use Symfony\Component\Routing\Route;

/**
 * Class RouteSubscriber.
 *
 * @package Drupal\form_helper_widget\Routing
 */
class RouteSubscriber extends RouteSubscriberBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityManagerInterface
   */
  protected $manager;

  /**
   * Constructs a RouteSubscriber object.
   *
   * @param \Drupal\Core\Entity\EntityManagerInterface $manager
   *   The entity type manager.
   */
  public function __construct(EntityManagerInterface $manager) {
    $this->manager = $manager;
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection) {

    // Create fieldgroup routes for every entity.
    foreach ($this->manager->getDefinitions() as $entity_type_id => $entity_type) {
      if ($route_name = $entity_type->get('field_ui_base_route')) {
        // Try to get the route from the current collection.
        if (!$entity_route = $collection->get($route_name)) {
          continue;
        }
        $path = $entity_route->getPath();

        $options = $entity_route->getOptions();

        // Special parameter used to easily recognize all Field UI routes.
        $options['_field_ui'] = TRUE;

        if (($bundle_entity_type = $entity_type->getBundleEntityType()) && $bundle_entity_type !== 'bundle') {
          $options['parameters'][$entity_type->getBundleEntityType()] = [
            'type' => 'entity:' . $entity_type->getBundleEntityType(),
          ];
        }

        $options['parameters']['field_group'] = [
          'type'        => 'field_group',
          'entity_type' => $entity_type->getBundleEntityType(),
        ];

        $defaults_delete = [
          'entity_type_id' => $entity_type_id,
          '_form'          => '\Drupal\form_helper_widget\Form\FormHelperWidgetDeleteForm',
        ];
        $defaults_add = [
          'entity_type_id' => $entity_type_id,
          '_form'          => '\Drupal\form_helper_widget\Form\FormHelperWidgetAddForm',
          '_title'         => 'Add group',
        ];

        // If the entity type has no bundles and it doesn't use {bundle} in its
        // admin path, use the entity type.
        if (strpos($path, '{bundle}') === FALSE) {
          $defaults_add['bundle'] = !$entity_type->hasKey('bundle') ? $entity_type_id : '';
          $defaults_delete['bundle'] = $defaults_add['bundle'];
        }

        // Routes to add translation widget.
        $route = new Route(
          "$path/form-display/add-translation-widget",
          ['context' => 'form'] + $defaults_add,
          ['_permission' => 'administer ' . $entity_type_id . ' form display'],
          $options
        );
        $collection->add("field_ui.form_helper_widget_add_$entity_type_id.form_display", $route);

        // Routes to delete translation widget.
        $route = new Route(
          "/admin/structure/form_helper_widget/{entityTypeId}/{bundle}/{mode}/{widgetId}",
          ['context' => 'form'] + $defaults_delete,
          ['_permission' => 'administer ' . $entity_type_id . ' form display'],
          $options
        );

        $collection->add("field_ui.form_helper_widget_delete_$entity_type_id", $route);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    // Come after field_ui, config_translation.
    $events[RoutingEvents::ALTER] = ['onAlterRoutes', -210];
    return $events;
  }

}
